# Slack_Bot_Advanced Template Usage Examples

This directory contains example configurations and usage scenarios for the slack_bot_advanced template.

## Available Examples

### 1. Basic Example (`basic/`)
A standard configuration that includes commonly used settings. This is a good starting point for most use cases.

### 2. Advanced Example (`advanced/`)
A comprehensive configuration that demonstrates all available features and options. Use this as a reference for complex setups.

### 3. Minimal Example (`minimal/`)
The simplest possible configuration with only required fields. Perfect for getting started quickly.

## Template Information

- **Name**: slack_bot_advanced
- **Category**: integration
- **Type**: integration
- **Version**: 1.0.0

## Configuration Fields

### Required Fields
- `slack_token`: Required configuration field
- `signing_secret`: Required configuration field
- `openai_key`: Required configuration field

### Optional Fields
- `port`: Optional configuration field
- `log_level`: Optional configuration field
- `max_tokens`: Optional configuration field
- `temperature`: Optional configuration field

## Quick Start

1. Choose an example that matches your needs (basic, advanced, or minimal)
2. Copy the `config.json` file from that example
3. Modify the configuration values to match your requirements
4. Use the MCP Development Toolkit to create your project:

```python
from mcp_dev_toolkit.templates import create_from_template
import json

# Load your configuration
with open('config.json', 'r') as f:
    config = json.load(f)

# Create project from template
result = create_from_template(
    template_name="slack_bot_advanced",
    project_name="my-project",
    config=config
)

print(f"Project created: {result['success']}")
if result['success']:
    print(f"Project path: {result['project_path']}")
```

## Command Line Usage

You can also use the command line interface:

```bash
# List available templates
mcp-toolkit templates list

# Create project from template
mcp-toolkit templates create \
    --template slack_bot_advanced \
    --name my-project \
    --config config.json
```

## Features

This template includes the following features:
- slash_commands
- message_events
- ai_responses
- thread_management

## Support

For questions or issues with this template, please refer to the MCP Development Toolkit documentation.
