# Advanced Example - Slack_Bot_Advanced

This is a advanced example configuration for the slack_bot_advanced template.

## Configuration

This example includes the following configuration:

```json
{
  "slack_token": "example_slack_token",
  "signing_secret": "example_signing_secret",
  "openai_key": "example_openai_key",
  "log_level": "INFO",
  "port": "advanced_port_value",
  "max_tokens": "advanced_max_tokens_value",
  "temperature": "advanced_temperature_value",
  "retry_attempts": 3,
  "timeout": 30,
  "batch_size": 100,
  "cache_enabled": true,
  "external_apis": {
    "primary": "https://api.example.com",
    "fallback": "https://backup-api.example.com"
  }
}
```

## Usage

Run the example script to create a project:

```bash
python create_project.py
```

Or use the configuration directly:

```python
from mcp_dev_toolkit.templates import create_from_template
import json

with open('config.json', 'r') as f:
    config = json.load(f)

result = create_from_template(
    template_name="slack_bot_advanced",
    project_name="my-project",
    config=config
)
```

## What This Example Demonstrates

This advanced example shows:
- All available configuration options
- Performance optimization settings
- Advanced features and integrations
- Comprehensive logging and monitoring setup

Use this example when you need full control and want to see all possibilities.


## Template Information

- **Template**: slack_bot_advanced
- **Category**: integration
- **Type**: integration
- **Features**: slash_commands, message_events, ai_responses, thread_management

## Customization

You can modify the `config.json` file to customize:
- `slack_token`: (Required) Configuration for slack_token
- `signing_secret`: (Required) Configuration for signing_secret
- `openai_key`: (Required) Configuration for openai_key
- `port`: (Optional) Configuration for port
- `log_level`: (Optional) Configuration for log_level
- `max_tokens`: (Optional) Configuration for max_tokens
- `temperature`: (Optional) Configuration for temperature
