#!/usr/bin/env python3
"""
Example Generator - Create example configurations and usage patterns
"""

from typing import Dict, Any, List


class ExampleGenerator:
    """Generate examples for templates."""
    
    def generate_example_configs(self, template_name: str) -> List[Dict[str, Any]]:
        """Generate example configurations for a template."""
        examples = [
            {
                "name": "basic_example",
                "description": "Basic server configuration",
                "config": {
                    "server_name": "my-basic-server",
                    "port": 8000,
                    "log_level": "INFO"
                }
            },
            {
                "name": "advanced_example", 
                "description": "Advanced server configuration",
                "config": {
                    "server_name": "my-advanced-server",
                    "port": 8080,
                    "log_level": "DEBUG"
                }
            }
        ]
        
        return examples
    
    def generate_usage_examples(self, template_name: str) -> str:
        """Generate usage examples for a template."""
        return f'''# Usage Examples for {template_name}

## Basic Usage

```bash
mcp-cli create server my-server --template {template_name}
```

## Advanced Usage

```bash
mcp-cli create server my-server --template {template_name} --config config.json
```

## Configuration

Example configuration file:

```json
{{
  "server_name": "my-server",
  "port": 8000,
  "log_level": "INFO"
}}
```
'''
