#!/usr/bin/env python3
"""
Template Scaffolder - Create template directory structures
"""

from pathlib import Path
from typing import Dict, Any
import json


class TemplateScaffolder:
    """Create and manage template directory structures."""
    
    def create_template_structure(self, template_path: str, template_info: dict) -> str:
        """Create the basic file structure for a template."""
        path = Path(template_path)
        path.mkdir(parents=True, exist_ok=True)
        
        # Create template config file
        config_file = path / "template_config.json"
        config_file.write_text(json.dumps(template_info, indent=2))
        
        return str(path)
    
    def scaffold_complete_template(self, template_name: str, output_path: str, 
                                  template_config: dict) -> str:
        """Create complete template directory structure."""
        template_dir = Path(output_path) / template_name
        template_dir.mkdir(parents=True, exist_ok=True)
        
        # Create subdirectories
        (template_dir / "examples").mkdir(exist_ok=True)
        (template_dir / "docs").mkdir(exist_ok=True)
        
        # Create basic template structure
        return self.create_template_structure(str(template_dir), template_config)
